@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_admin_errata == "NO") {
 
@@ -56,15 +56,12 @@ $num_voti = count($voti);
 for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
 $dati_voto = explode($separatore_campi_file_voti, $voti[$num1]);
 $num_calciatore = $dati_voto[($num_colonna_numcalciatore_file_voti-1)];
-$num_calciatore = str_replace("
-","",$num_calciatore);
+$num_calciatore = togli_acapo($num_calciatore);
 $voto_tot[$num_calciatore] = $dati_voto[($num_colonna_vototot_file_voti-1)];
-$voto_tot[$num_calciatore] = str_replace("
-","",$voto_tot[$num_calciatore]);
+$voto_tot[$num_calciatore] = togli_acapo($voto_tot[$num_calciatore]);
 $voto_tot[$num_calciatore] = str_replace(",",".",$voto_tot[$num_calciatore]);
 $voto_giornale[$num_calciatore] = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
-$voto_giornale[$num_calciatore] = str_replace("
-","",$voto_giornale[$num_calciatore]);
+$voto_giornale[$num_calciatore] = togli_acapo($voto_giornale[$num_calciatore]);
 } # fine for $num1
 
 
@@ -74,8 +71,7 @@ $num_linee_file_giornata = count($file_giornata);
 $num_partite = 0;
 $partite = "";
 for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
-$linea = str_replace("
-","",$file_giornata[$num1]);
+$linea = togli_acapo($file_giornata[$num1]);
 # leggo le formazioni
 if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
 if ($leggendo_formazioni == "SI") {
@@ -128,16 +124,14 @@ $dati_calciatore = explode(",", ${$formazione}[$num2]);
 $num_calciatore = $dati_calciatore[0];
 if ($voto_tot[$num_calciatore] == 0 and $voto_giornale[$num_calciatore] == 0) {
 $ruolo_calc = $dati_calciatore[2];
-$ruolo_calc = ereg_replace("
-","",$ruolo_calc);
+$ruolo_calc = togli_acapo($ruolo_calc);
 $nome_sostituisci = "sostituisci_$ruolo_calc";
 $$nome_sostituisci++;
 } # fine if ($voto_tot[$num_calciatore] == 0 and...
 else {
 $nome_calc = $dati_calciatore[1];
 ${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
-${$formazione}[$num2] = ereg_replace("
-","",${$formazione}[$num2]);
+${$formazione}[$num2] = togli_acapo(${$formazione}[$num2]);
 ${$formazione}[$num2] .= ",".$voto_tot[$num_calciatore]."
 ";
 $voti_tot[$giocatore] = $voti_tot[$giocatore] + $voto_tot[$num_calciatore];
@@ -153,11 +147,9 @@ $dati_calciatore = explode(",", ${$formazione}[$num2]);
 $num_calciatore = $dati_calciatore[0];
 if ($voto_tot[$num_calciatore] != 0 or $voto_giornale[$num_calciatore] != 0) {
 $ruolo_calc = $dati_calciatore[2];
-$ruolo_calc = ereg_replace("
-","",$ruolo_calc);
+$ruolo_calc = togli_acapo($ruolo_calc);
 $nome_sostituisci = "sostituisci_$ruolo_calc";
-${$formazione}[$num2] = ereg_replace("
-","",${$formazione}[$num2]);
+${$formazione}[$num2] = togli_acapo(${$formazione}[$num2]);
 ${$formazione}[$num2] .= ",".$voto_tot[$num_calciatore]."
 ";
 if ($$nome_sostituisci >= 1) {
