@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_admin_errata == "NO") {
 
@@ -149,8 +149,7 @@ $giornata_in_corso = "";
 $scontri_diretti = "#@& scontri #@&
 ";
 for ($num1 = 0 ; $num1 < $num_linee_file_scontri; $num1++) {
-$linea_file_scontri = str_replace("
-","",$file_scontri[$num1]);
+$linea_file_scontri = togli_acapo($file_scontri[$num1]);
 if ($campionato_in_corso == "SI") {
 if ($linea_file_scontri == "</campionato>") break;
 
