@@ -21,7 +21,7 @@
 
 
 $parla = "NO";
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 
 
@@ -71,7 +71,7 @@ $voti_esistenti = "NO";
 if ($giornata_ultima) $file_giornata = file("$percorso_cartella_dati/$giornata");
 $num_linee_file_giornata = count($file_giornata);
 for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
-$linea = substr($file_giornata[$num1],0,-1);
+$linea = togli_acapo($file_giornata[$num1]);
 if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
 if ($leggendo_formazioni == "SI") {
 if ($linea == "#@& formazione #@&") $giocatore = "";
@@ -130,8 +130,7 @@ $giocatore = key($pass);
 $nome_posizione[$num1] = $giocatore;
 
 $soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
-$soprannome_squadra[3] = str_replace("
-","",$soprannome_squadra[3]);
+$soprannome_squadra[3] = togli_acapo($soprannome_squadra[3]);
 if ($soprannome_squadra[3]) {
 $nome_sqadra_memo[$giocatore] = $soprannome_squadra[3];
 $soprannome_squadra = "<b>".$soprannome_squadra[3]."</b>";
@@ -243,7 +242,7 @@ $num_linee_file_giornata_p = count($file_giornata_p);
 $leggendo_punteggi = "NO";
 $punteggi_esistenti_p = "NO";
 for($num2 = 0 ; $num2 < $num_linee_file_giornata_p; $num2++) {
-$linea = substr($file_giornata_p[$num2],0,-1);
+$linea = togli_acapo($file_giornata_p[$num2]);
 if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
 if ($leggendo_punteggi == "SI") {
 $punteggi_p[$num3] = $file_giornata_p[$num2];
