@@ -19,7 +19,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 if ($pass_errata != "SI") {
 
 
@@ -55,11 +55,9 @@ $costo = $dati_calciatore[3];
 $proprietario_vero = $proprietario;
 $vecchio_proprietario = $dati_calciatore[6];
 $vecchio_costo = $dati_calciatore[7];
-$vecchio_costo = ereg_replace("
-","",$vecchio_costo);
+$vecchio_costo = togli_acapo($vecchio_costo);
 $nuovo_costo = $dati_calciatore[8];
-$nuovo_costo = ereg_replace("
-","",$nuovo_costo);
+$nuovo_costo = togli_acapo($nuovo_costo);
 $tempo_off = $dati_calciatore[5];
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
@@ -89,17 +87,14 @@ $num_calciatori_completi = count($calciatori_completi);
 for ($num1 = 0 ; $num1 < $num_calciatori_completi ; $num1++) {
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori_completi[$num1]);
 $numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
-$numero = ereg_replace("
-","",$numero);
+$numero = togli_acapo($numero);
 if ($num_calciatore == $numero) {
 $trovato = "SI";
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
-$nome = ereg_replace("
-","",$nome);
+$nome = togli_acapo($nome);
 $nome = ereg_replace("\"","",$nome);
 $ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
-$ruolo = ereg_replace("
-","",$ruolo);
+$ruolo = togli_acapo($ruolo);
 if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
 if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
 if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
