@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
@@ -55,8 +55,7 @@ reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
 $giocatore = key($pass);
 $soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
-$soprannome_squadra[3] = str_replace("
-","",$soprannome_squadra[3]);
+$soprannome_squadra[3] = togli_acapo($soprannome_squadra[3]);
 $soprannome_squadra = $soprannome_squadra[3];
 if (!$soprannome_squadra) $soprannome_squadra = "di $giocatore";
 echo "<option value=\"$giocatore\">$soprannome_squadra</option>";
@@ -89,8 +88,7 @@ for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
 if ($nome_utente == $dati_scambio[4]) {
 $tempo_off = $dati_scambio[7];
-$tempo_off = ereg_replace("
-","",$tempo_off);
+$tempo_off = togli_acapo($tempo_off);
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
