@@ -20,14 +20,13 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
 
 if ($aggiungi_messaggio) {
-$nuovo_messaggio = ereg_replace("
-","",$nuovo_messaggio);
+$nuovo_messaggio = togli_acapo($nuovo_messaggio);
 $nuovo_messaggio = stripslashes($nuovo_messaggio);
 $file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
 flock($file_messaggi,2);
