@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
@@ -100,17 +100,14 @@ $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
 $numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
-$numero = ereg_replace("
-","",$numero);
+$numero = togli_acapo($numero);
 if ($num_calciatore == $numero) {
 $trovato = "SI";
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
-$nome = ereg_replace("
-","",$nome);
+$nome = togli_acapo($nome);
 $nome = ereg_replace("\"","",$nome);
 $ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
-$ruolo = ereg_replace("
-","",$ruolo);
+$ruolo = togli_acapo($ruolo);
 if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
 if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
 if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
