@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
@@ -203,8 +203,7 @@ for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
 # se lo scambio  scaduto non lo riscrivo
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
 $tempo_off = $dati_scambio[7];
-$tempo_off = ereg_replace("
-","",$tempo_off);
+$tempo_off = togli_acapo($tempo_off);
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
