@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
@@ -68,8 +68,7 @@ $calciatori_richiesti = explode(";", $calciatori_richiesti);
 $num_calciatori_richiesti = count($calciatori_richiesti);
 $soldi_richiesti = $dati_scambio[6];
 $tempo_off = $dati_scambio[7];
-$tempo_off = ereg_replace("
-","",$tempo_off);
+$tempo_off = togli_acapo($tempo_off);
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
@@ -208,8 +207,7 @@ $nome = $dati_calciatore[1];
 $ruolo = $dati_calciatore[2];
 $costo = $dati_calciatore[3];
 $tempo_off = $dati_calciatore[5];
-$tempo_off = ereg_replace("
-","",$tempo_off);
+$tempo_off = togli_acapo($tempo_off);
 $scritto_linea = "NO";
 for ($num2 = 0 ; $num2 < $num_calciatori_richiesti ; $num2++) {
 if ($numero == $calciatori_richiesti[$num2]) {
@@ -283,8 +281,7 @@ for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
 # se lo scambio  scaduto non lo riscrivo
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
 $tempo_off = $dati_scambio[7];
-$tempo_off = ereg_replace("
-","",$tempo_off);
+$tempo_off = togli_acapo($tempo_off);
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
