@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
@@ -81,8 +81,7 @@ if ($nome_squadra == $giocatore or $nome_squadra == "tutti") {
 
 $dati_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
 $soprannome_squadra = $dati_squadra[3];
-$soprannome_squadra = ereg_replace("
-","",$soprannome_squadra);
+$soprannome_squadra = togli_acapo($soprannome_squadra);
 echo "<center><font size=+1>";
 if ($soprannome_squadra) echo "<b>$soprannome_squadra</b>";
 else echo "Squadra";
