@@ -19,7 +19,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 if ($pass_errata != "SI") {
 
 
